============
Installation
============

At the command line pip::

    $ pip install galight

Or, using through github channel (see guidance there):

https://github.com/dartoon/galight 

Note that, if python2 is used. Please install the lenstronomy at version == 1.3.0

